@@ -4,6 +4,7 @@ from .get_contents import AllPostGetter
 from .question import app
 from .utils import (console, get_choices, get_code, get_post_from_questionary,
                     handle_exception)
+import typer 
 
 
 @handle_exception
@@ -14,7 +15,8 @@ def get_post_from_question(titles: list):
 
 
 @app.command()
-def search_posts(pattern: str):
+def search_posts(pattern=typer.Argument(..., help='String pattern')):
+    """Search post based on the string pattern"""
     (
         titles_to_post,
         titles_to_code,
